@@ -5,7 +5,8 @@ available to Controllers. This module is available to templates as 'h'.
 """
 from webhelpers.html import literal
 from webhelpers.html.tags import *
-from webhelpers.html.secure_form import secure_form
+from webhelpers.pylonslib.secure_form import secure_form
 from webhelpers.pylonslib import Flash as _Flash
+from pylons import url
 
 flash = _Flash()
